
# data prepare
library(tidyverse)
df <- read.csv('data/Orthogroups.GeneCount.tsv', row.names = 1)
df_uniq <- read.csv('data/Orthogroups_UnassignedGenes.tsv', row.names = 1)
df <- df[,1:(ncol(df)-1)]
df_uniq[df_uniq != ''] <- 1
df_uniq[df_uniq == ''] <- 0
df <- rbind(df, df_uniq)

# core & uniq gene
df_summary <- data.frame(gene=rownames(df))
df_summary$type <- apply(df, 1, function(x) if (length(x[x!=0]) == 1) colnames(df)[which(x != 0)] else NA)
df_summary$type[apply(df, 1, function(x) all(x != 0))] <- 'core'
df_summary[is.na(df_summary)] <- 'accessory'

st_u <- data.frame(t(table(df_summary$type))) %>% rename(strain=Var2) %>%select(strain, Freq) %>%
  merge(., data.frame(strain = colnames(df)), all.y=T)
st_u[is.na(st_u)] <- 0

# 饼图
library(ggpubr) 
pdata1 <- data.frame(group = factor(c('core','unique','accessory'), levels = c('core','unique','accessory')), 
                     freq = c(nrow(df_summary %>% filter(type=='core')),sum(st_u$Freq), nrow(df_summary %>% filter(type=='accessory'))))
piedata1 <- pdata1%>% 
  mutate(labs=paste0(freq,'\n(',100*round(freq/sum(freq),4),'%)')) 
ggpie(piedata1, 'freq', #绘图，只用写频数就行，切记不用再写分组 
      fill = 'group', palette = 'jco',#颜色板为jco. 
      label = 'labs', lab.pos = 'in', lab.font = c(4, 'white'))+ #设置标签，标签的位置在图的内部，标签的大小为4， 颜色为白色. 
  theme(legend.position = "top")+ labs(fill="")
ggsave('result/pie.png')


# 花瓣图
library(plotrix)
ellipse_col <- c('#6181BD4E','#F348004E','#64A10E4E','#9300264E','#464E044E','#049a0b4E','#daa5204E','#1e90ff4e','#ba55d34E')#椭圆的颜色设置
flower_plot <- function(sample, otu_num, core_otu, start=90, a, b, r, ellipse_col, circle_col) {
  par( bty = 'n', ann = F, xaxt = 'n', yaxt = 'n', mar = c(1,1,1,1))#start为椭圆的起始位置, a为椭圆的短轴, b为椭圆的长轴, r为中心圆的半径
  plot(c(0,10),c(0,10),type='n')
  n   <- length(sample)
  deg <- 360 / n
  res <- lapply(1:n, function(t){
    draw.ellipse(x = 5 + cos((start + deg * (t - 1)) * pi / 180), #绘制椭圆
                 y = 5 + sin((start + deg * (t - 1)) * pi / 180), 
                 col = ellipse_col[t],
                 border = ellipse_col[t],
                 a = a, b = b, angle = deg * (t - 1))
    text(x = 5 + 2.5 * cos((start + deg * (t - 1)) * pi / 180),#在图上设置每个样品的otu_num数目
         y = 5 + 2.5 * sin((start + deg * (t - 1)) * pi / 180),
         otu_num[t])
    
    if (deg * (t - 1) < 180 && deg * (t - 1) > 0 ) {
      text(x = 5 + 3.3 * cos((start + deg * (t - 1)) * pi / 180),#设置每个样品名
           y = 5 + 3.3 * sin((start + deg * (t - 1)) * pi / 180),
           sample[t],
           srt = deg * (t - 1) - start,
           adj = 1,
           cex = 1
      )
    } else {
      text(x = 5 + 3.3 * cos((start + deg * (t - 1)) * pi / 180),
           y = 5 + 3.3 * sin((start + deg * (t - 1)) * pi / 180),
           sample[t],
           srt = deg * (t - 1) + start,
           adj = 0,
           cex = 1
      )
    }
  })
  draw.circle(x = 5, y = 5, r = r, col = circle_col, border = NA)#绘制中心圆
  text(x = 5, y = 5, paste('Core:', core_otu))#设置中心圆名字
}  

png('result/flower.png', w=500, h=500)
flower_plot(sample = st_u$strain, otu_num = st_u$Freq, core_otu = nrow(df_summary %>% filter(type=='core')),
            a = 0.7, b = 2, r = 0.8, ellipse_col = ellipse_col, circle_col = 'white')
dev.off()

# upset
library(UpSetR)
upsetdf <- as.data.frame(lapply(df, as.numeric))
upsetdf [upsetdf != 0] <- 1
upset(upsetdf, nset = 9,
      order.by = 'freq')
